@@ -1,12 +1,17 @@
 package Path::Resolver::Resolver::DataSection;
-our $VERSION = '2.002';
+our $VERSION = '3.092200';
 
 # ABSTRACT: find content in a package's Data::Section content
 use Moose;
 with 'Path::Resolver::Role::Resolver';
 
-use File::Spec::Unix;
+use namespace::autoclean;
 
+use File::Spec::Unix;
+use Moose::Util::TypeConstraints;
+use Path::Resolver::SimpleEntity;
+
+sub native_type { class_type('Path::Resolver::SimpleEntity') }
 
 
 has module => (
@@ -28,7 +33,7 @@ sub BUILD {
   eval "require $module; 1" or die;
 }
 
-sub content_for {
+sub entity_at {
   my ($self, $path) = @_;
 
   my $filename = File::Spec::Unix->catfile(@$path);
@@ -36,11 +41,11 @@ sub content_for {
   my $content_ref = $self->module->$method($filename);
 
   return unless defined $content_ref;
-  return $content_ref;
+
+  return Path::Resolver::SimpleEntity->new({ content_ref => $content_ref });
 }
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
+1;
 
 __END__
 
@@ -52,14 +57,24 @@ Path::Resolver::Resolver::DataSection - find content in a package's Data::Sectio
 
 =head1 VERSION
 
-version 2.002
+version 3.092200
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
+
+  my $resolver = Path::Resolver::Resolver::DataSection->new({
+    module => 'YourApp::Config::InData',
+  });
+
+  my $simple_entity = $resolver->entity_for('foo/bar.txt');
 
 This class assumes that you will give it the name of another package and that
 that package uses L<Data::Section|Data::Section> to retrieve named content from
 its C<DATA> blocks and those of its parent classes.
 
+The native type of this resolver is a class type of
+L<Path::Resolver::SimpleEntity|Path::Resolver::SimpleEntity> and it has no
+default converter.
+
 =head1 ATTRIBUTES
 
 =head2 module
@@ -81,7 +96,7 @@ a package.  The default is Data::Section's default: C<section_data>.
 This software is copyright (c) 2009 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
+the same terms as the Perl 5 programming language system itself.
 
 =cut 
 
