@@ -1,13 +1,14 @@
 package Path::Resolver::Resolver::DistDir;
-our $VERSION = '2.002';
+our $VERSION = '3.092200';
 
 # ABSTRACT: find content in a prebound CPAN distribution's "ShareDir"
 use Moose;
-with 'Path::Resolver::Role::Resolver';
+with 'Path::Resolver::Role::FileResolver';
+
+use namespace::autoclean;
 
 use File::ShareDir ();
 use File::Spec;
-use Path::Resolver::Util;
 
 
 has dist_name => (
@@ -16,7 +17,7 @@ has dist_name => (
   required => 1,
 );
 
-sub content_for {
+sub entity_at {
   my ($self, $path) = @_;
   my $dir = File::ShareDir::dist_dir($self->dist_name);
 
@@ -25,11 +26,10 @@ sub content_for {
     File::Spec->catfile(@$path),
   );
 
-  return Path::Resolver::Util->_content_at_abs_path($abs_path);
+  return Path::Class::File->new($abs_path);
 }
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
+1;
 
 __END__
 
@@ -41,7 +41,24 @@ Path::Resolver::Resolver::DistDir - find content in a prebound CPAN distribution
 
 =head1 VERSION
 
-version 2.002
+version 3.092200
+
+=head1 SYNOPSIS
+
+  my $resolver = Path::Resolver::Resolver::DistDir->new({
+    dist_name => 'YourApp-Files',
+  });
+
+  my $simple_entity = $resolver->entity_for('foo/bar.txt');
+
+This resolver looks for files on disk in the shared resource directory of the
+named distribution.  For more information on sharedirs, see
+L<File::ShareDir|File::ShareDir>.
+
+This resolver does the
+L<Path::Resolver::Role::FileResolver|Path::Resolver::Role::FileResolver> role,
+meaning its native type is Path::Resolver::Types::AbsFilePath and it has a
+default converter to convert to Path::Resolver::SimpleEntity.
 
 =head1 ATTRIBUTES
 
@@ -60,7 +77,7 @@ L<File::ShareDir|File::ShareDir>.
 This software is copyright (c) 2009 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
+the same terms as the Perl 5 programming language system itself.
 
 =cut 
 
